pyjabber.webpage package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyjabber.webpage.api

Submodules
----------

pyjabber.webpage.adminPage module
---------------------------------

.. automodule:: pyjabber.webpage.adminPage
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.webpage
   :members:
   :undoc-members:
   :show-inheritance:
